@@ -22,7 +22,7 @@
 use super::{
     Array, ArrayData, BinaryOffsetSizeTrait, BooleanArray, DecimalArray,
     FixedSizeBinaryArray, FixedSizeListArray, GenericBinaryArray, GenericListArray,
-    GenericStringArray, NullArray, OffsetSizeTrait, PrimitiveArray,
+    GenericStringArray, MapArray, NullArray, OffsetSizeTrait, PrimitiveArray,
     StringOffsetSizeTrait, StructArray,
 };
 
@@ -117,6 +117,12 @@ impl<OffsetSize: OffsetSizeTrait> PartialEq for GenericListArray<OffsetSize> {
     }
 }
 
+impl PartialEq for MapArray {
+    fn eq(&self, other: &Self) -> bool {
+        equal(self.data(), other.data())
+    }
+}
+
 impl PartialEq for FixedSizeListArray {
     fn eq(&self, other: &Self) -> bool {
         equal(self.data(), other.data())
@@ -246,6 +252,9 @@ fn equal_values(
             _ => unreachable!(),
         },
         DataType::Float16 => unreachable!(),
+        DataType::Map(_, _) => {
+            list_equal::<i32>(lhs, rhs, lhs_nulls, rhs_nulls, lhs_start, rhs_start, len)
+        }
     }
 }
 
@@ -673,7 +682,8 @@ mod tests {
         .add_buffer(Buffer::from(vec![0i32, 2, 3, 4, 6, 7, 8].to_byte_slice()))
         .add_child_data(c_values.data().clone())
         .null_bit_buffer(Buffer::from(vec![0b00001001]))
-        .build();
+        .build()
+        .unwrap();
 
         let d_values = Int32Array::from(vec![
             Some(1),
@@ -694,7 +704,8 @@ mod tests {
         .add_buffer(Buffer::from(vec![0i32, 2, 3, 4, 6, 7, 8].to_byte_slice()))
         .add_child_data(d_values.data().clone())
         .null_bit_buffer(Buffer::from(vec![0b00001001]))
-        .build();
+        .build()
+        .unwrap();
         test_equal(&c, &d, true);
     }
 
@@ -1045,7 +1056,8 @@ mod tests {
         .len(5)
         .add_child_data(strings.data_ref().clone())
         .add_child_data(ints.data_ref().clone())
-        .build();
+        .build()
+        .unwrap();
         let a = crate::array::make_array(a);
 
         let b = ArrayData::builder(DataType::Struct(vec![
@@ -1056,7 +1068,8 @@ mod tests {
         .len(5)
         .add_child_data(strings.data_ref().clone())
         .add_child_data(ints_non_null.data_ref().clone())
-        .build();
+        .build()
+        .unwrap();
         let b = crate::array::make_array(b);
 
         test_equal(a.data_ref(), b.data_ref(), true);
@@ -1071,7 +1084,8 @@ mod tests {
         .len(5)
         .add_child_data(strings.data_ref().clone())
         .add_child_data(c_ints_non_null.data_ref().clone())
-        .build();
+        .build()
+        .unwrap();
         let c = crate::array::make_array(c);
 
         test_equal(a.data_ref(), c.data_ref(), false);
@@ -1085,7 +1099,8 @@ mod tests {
         .null_bit_buffer(Buffer::from(vec![0b00011110]))
         .len(5)
         .add_child_data(a.data_ref().clone())
-        .build();
+        .build()
+        .unwrap();
         let a = crate::array::make_array(a);
 
         // reconstruct b, but with different data where the first struct is null
@@ -1104,7 +1119,8 @@ mod tests {
         .len(5)
         .add_child_data(strings.data_ref().clone())
         .add_child_data(ints_non_null.data_ref().clone())
-        .build();
+        .build()
+        .unwrap();
 
         let b = ArrayData::builder(DataType::Struct(vec![Field::new(
             "f3",
@@ -1114,7 +1130,8 @@ mod tests {
         .null_bit_buffer(Buffer::from(vec![0b00011110]))
         .len(5)
         .add_child_data(b)
-        .build();
+        .build()
+        .unwrap();
         let b = crate::array::make_array(b);
 
         test_equal(a.data_ref(), b.data_ref(), true);
@@ -1146,7 +1163,8 @@ mod tests {
         .null_bit_buffer(Buffer::from(vec![0b00001010]))
         .len(5)
         .add_child_data(strings1.data_ref().clone())
-        .build();
+        .build()
+        .unwrap();
         let a = crate::array::make_array(a);
 
         let b = ArrayData::builder(DataType::Struct(vec![Field::new(
@@ -1157,7 +1175,8 @@ mod tests {
         .null_bit_buffer(Buffer::from(vec![0b00001010]))
         .len(5)
         .add_child_data(strings2.data_ref().clone())
-        .build();
+        .build()
+        .unwrap();
         let b = crate::array::make_array(b);
 
         test_equal(a.data_ref(), b.data_ref(), true);
@@ -1178,7 +1197,8 @@ mod tests {
         .null_bit_buffer(Buffer::from(vec![0b00001011]))
         .len(5)
         .add_child_data(strings3.data_ref().clone())
-        .build();
+        .build()
+        .unwrap();
         let c = crate::array::make_array(c);
 
         test_equal(a.data_ref(), c.data_ref(), false);
